@@ -1,5 +1,5 @@
 package GitLab::API::v4::Constants;
-$GitLab::API::v4::Constants::VERSION = '0.10';
+$GitLab::API::v4::Constants::VERSION = '0.11';
 =encoding utf8
 
 =head1 NAME
@@ -25,6 +25,15 @@ our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
 =head1 CONSTANTS
 
+=head2 $GITLAB_ACCESS_LEVEL_NO_ACCESS
+
+C<0>
+
+=cut
+
+const our $GITLAB_ACCESS_LEVEL_NO_ACCESS => 0;
+push @EXPORT_OK, '$GITLAB_ACCESS_LEVEL_NO_ACCESS';
+
 =head2 $GITLAB_ACCESS_LEVEL_GUEST
 
 C<10>
@@ -72,13 +81,15 @@ push @EXPORT_OK, '$GITLAB_ACCESS_LEVEL_OWNER';
 
 =head2 @GITLAB_ACCESS_LEVELS
 
-An array containing the values for L</$GITLAB_ACCESS_LEVEL_GUEST>,
+An array containing the values for L</$GITLAB_ACCESS_LEVEL_NO_ACCESS>,
+L</$GITLAB_ACCESS_LEVEL_GUEST>,
 L</$GITLAB_ACCESS_LEVEL_REPORTER>, L</$GITLAB_ACCESS_LEVEL_DEVELOPER>,
 L</$GITLAB_ACCESS_LEVEL_MASTER>, and L</$GITLAB_ACCESS_LEVEL_OWNER>.
 
 =cut
 
 const our @GITLAB_ACCESS_LEVELS => (
+    $GITLAB_ACCESS_LEVEL_NO_ACCESS,
     $GITLAB_ACCESS_LEVEL_GUEST,
     $GITLAB_ACCESS_LEVEL_REPORTER,
     $GITLAB_ACCESS_LEVEL_DEVELOPER,
